@@ -1,5 +1,5 @@
 from typing import Dict, List, Union
-from urllib.parse import quote_plus
+from urllib.parse import quote_plus, quote
 
 import jinja2
 
@@ -90,11 +90,6 @@ def generate_table(table: List[List[str]]) -> str:
                 output += "| " + "".ljust(max_cell_length[idx_col], "-") + " "
             output += "|\n"
 
-    # add last empty row
-    for cell in max_cell_length.values():
-        output += "| " + "".ljust(cell, " ") + " "
-    output += "|\n"
-
     return output
 
 
@@ -213,6 +208,12 @@ class MarkdownTemplate(object):
         Filter. display heading menu, heading number automatically calculated
         from previous heading and depth provided
         """
+        if depth == 0:
+            # If we process multiple files, this needs to be reset manually
+            # because there is only one instance of this class
+            self.toc = {}
+            self.auto_generated_heading = 0
+
         if not html_id:
             self.auto_generated_heading = self.auto_generated_heading + 1
             html_id = f"autogenerated_heading_{self.auto_generated_heading}"
@@ -294,17 +295,20 @@ class MarkdownTemplate(object):
         """
         Badge as markdown image link if badge_as_image option set otherwise Badge as text
         """
+        if value:
+            text_badge = f"{name}: {value}"
+        else:
+            text_badge = name
+
         if self.config.template_md_options.get("badge_as_image") and not show_text:
             value_str = ""
-            if value and len(value) > 0:
-                value_str = "-" + quote_plus(value)
-            name = quote_plus(name)
-            color = quote_plus(color)
-            return f"![badge](https://img.shields.io/badge/{name}{value_str}-{color})"
+            if value:
+                value_str = "-" + quote(value)
+            name = quote(name)
+            color = quote(color)
+            return f"![{text_badge}](https://img.shields.io/badge/{name}{value_str}-{color})"
         else:
-            if value and len(value) > 0:
-                return f"[{name}: {value}]"
-            return f"[{name}]"
+            return f"[{text_badge}]"
 
     def properties_table(self, schema: SchemaNode) -> List[List]:
         """
@@ -365,13 +369,16 @@ class MarkdownTemplate(object):
 
         schema_type = schema.type_name
         default_value = schema.default_value
+        schema_format = schema.format
         type_info.append(["Type", "`combining`" if jinja_filters.is_combining(schema) else f"`{schema_type}`"])
         if jinja_filters.deprecated(self.config, schema):
             type_info.append(["**Deprecated**", self.badge("Deprecated", "red")])
 
-        if schema.type_name == const.TYPE_OBJECT:
+        if schema_format:
+            type_info.append(["**Format**", f"`{schema_format}`"])
+        if schema_type == const.TYPE_OBJECT:
             type_info.append(["**Additional properties**", self.additional_properties(schema)])
-        if schema.default_value:
+        if default_value:
             type_info.append(["**Default**", f"`{default_value}`"])
         if schema.should_be_a_link(self.config):
             schema_link_name = schema.links_to.link_name
